#
# spec file for package clojure
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clojure
Version:        1.11.1.1155
Release:        bp155.1.5
Summary:        A dynamic programming language that targets the JVM
License:        EPL-1.0
Group:          Development/Languages/Other
URL:            https://clojure.org/
Source0:        https://download.clojure.org/install/clojure-tools-%{version}.tar.gz
BuildRequires:  fdupes
Requires:       java >= 1.8.0
Requires:       rlwrap
BuildArch:      noarch

%description
Clojure is a dynamic programming language that targets the Java
Virtual Machine (and the CLR, and JavaScript). It is designed to be a
general-purpose language, combining the approachability and
interactive development of a scripting language with an
infrastructure for multithreaded programming. Clojure is a
compiled language - it compiles directly to JVM bytecode, yet remains
completely dynamic. Every feature supported by Clojure is supported at
runtime. Clojure provides access to the Java frameworks, with
optional type hints and type inference, to ensure that calls to Java
can avoid reflection.

%prep
%setup -q -n clojure-tools
sed -i "s/#!\/usr\/bin\/env bash/#!\/bin\/bash/" clj
sed -i "s/#!\/usr\/bin\/env bash/#!\/bin\/bash/" clojure
sed -i "s|PREFIX|%{_datadir}/clojure|" clojure
sed -i "s|BINDIR|%{_bindir}|" clj

%build

%install
install -Dm644 deps.edn "%{buildroot}/%{_datadir}/clojure/deps.edn"
install -Dm644 example-deps.edn "%{buildroot}/%{_datadir}/clojure/example-deps.edn"
install -Dm644 exec.jar "%{buildroot}/%{_datadir}/clojure/libexec/exec.jar"
install -Dm644 clojure-tools-%{version}.jar "%{buildroot}/%{_datadir}/clojure/libexec/clojure-tools-%{version}.jar"
install -Dm755 clojure "%{buildroot}/%{_bindir}/clojure"
install -Dm755 clj "%{buildroot}/%{_bindir}/clj"
install -Dm644 clojure.1 "%{buildroot}%{_mandir}/man1/clojure.1"
install -Dm644 clj.1 "%{buildroot}%{_mandir}/man1/clj.1"

%fdupes %{buildroot}/%{_prefix}

%files
%dir %{_datadir}/clojure
%dir %{_datadir}/clojure/libexec
%{_bindir}/clj
%{_bindir}/clojure
%{_datadir}/clojure/deps.edn
%{_datadir}/clojure/example-deps.edn
%{_datadir}/clojure/libexec/exec.jar
%{_datadir}/clojure/libexec/clojure-tools-%{version}.jar
%{_mandir}/man1/*

%changelog
* Sun Aug 28 2022 Chris Coutinho <chrisbcoutinho@gmail.com>
- Update to 1.11.1.1155
  * Fix `clj`: replace BINDIR with 'bindir' during install
* Thu May 27 2021 Petr Cervinka <petr@cervinka.net>
- Update to 1.10.3.855:
  * Fix in applying :jvm-opts with -X execution on Windows
- Changes in 1.10.3.849:
  * Adds support for a trailing map of kvs in -X calls (similar to Clojure 1.11 trailing map to vararg calls)
  * Updates all Maven deps to latest (maven-resolver 1.7.0, maven core 1.8.3) to address these security concerns
  - CVE-2020-13956 - bumps deps on Apache HttpClient used by Maven
  - CVE-2021-26291 - potential security problems regarding Maven repositories:
  - Due to the possibility of MITM (man in the middle) attacks, http repo access is now blocked by default.
    tools.deps/Clojure CLI has always used https repos in the default repository list (central and clojars),
    so this mostly impacts any explicit http repositories defined in deps.edn
  - Concerns over the "hijacking" of repository urls by transitive pom deps (or their super poms) to download
    artifacts from malicious repos. Maven made no changes here, but did clarify how repos are resolved on this page.
    From a deps perspective, we only use repositories declared in the top-level deps.edn (if transitive deps need a custom repo,
    you will need to add it at top-level too). For tools.deps use of pom dependencies, we are providing the repos of
    the top deps.edn file (which should always put Maven Central and Clojars first), then deferring to Maven for the rest.
  * Use tools.deps.alpha 0.11.922
- Changes in 1.10.3.839:
  * Fix Linux installer breakage in 1.10.3.833
- Changes in 1.10.3.833:
  * TDEPS-177 - Fix Maven mirrors to look up by id, not name
  * Remove flag when fetching git deps so that older git versions work
  * Tweak some warning messages
  * Clean up scripts to simplify variable replacement
  * Use tools.deps.alpha 0.11.918
- Changes in 1.10.3.822:
  * Fix issue with git deps where new commits on branches were not fetched
- Changes in 1.10.3.814:
  * git deps: switch from using jgit to shelling out to git (must be git >= 2.5)
  * New env vars for control:
  - GITLIBS_COMMAND - command to invoke when shelling out to git, default = git
  - GITLIBS_DEBUG - set to true to print git commands and output to stderr, default = false
  * Made git fetch only when shas can’t be resolved to improve performance
  * Bump dep versions for tools.cli and aws api to latest
  * Use tools.deps.alpha 0.11.905
- Changes in 1.10.2.796:
  * Fix clj -X:deps git-resolve-tags to update the sha to match the tag
  * Perf improvements for git or local deps using pom.xml
  * Use tools.deps.alpha 0.9.884
- Changes in 1.10.2.790:
  * Add -version and --version options
  * TDEPS-56 - Fix main-opts and jvm-opts word splitting on spaces
  * TDEPS-125 - Use JAVA_CMD if set (thanks Gregor Middell!)
  * Add warning if :paths or :extra-paths refers to a directory outside the project root (in the future will become an error)
  * Use tools.deps.alpha 0.9.871
* Wed Jan 27 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.10.2:
  * Interop / JVM:
  - CLJ-1472 Ensure monitor object is on stack, for verifiers
  - CLJ-2517 More fixes for invocation of static interface methods with primitive args
  - CLJ-2492 Remove uses of deprecated Class.newInstance()
  - CLJ-2534 Fix javadoc urls for JDK 11+
  - CLJ-2571 Add Throwable return type hint to ex-cause
  - CLJ-2572 Avoid reflection in clojure.data
  - CLJ-2502 Fix reflection warnings in clojure.stacktrace/print-stack-trace
  - CLJ-2597 proxy should emit Java 1.8 bytecode
  * Core:
  - CLJ-2580 Fix case expression branch analysis that resulted in compilation error
  - CLJ-2564 Improve error message for case
  - CLJ-2585 nth with not-found on regex matcher returns not-found on last group index
  - CLJ-1364 vector-of does not implement equals or hashing methods
  - CLJ-2549 vector-of does not implement IObj for metadata
  - CLJ-1187 quoted metadata on empty literal colls is lost
  - CLJ-2459 ExceptionInInitializerError if jars executed with java -jar
  * Printing:
  - CLJ-2469 Fix errors in printing some maps with namespace syntax
  - CLJ-1445 pprint doesn't print collection metadata when *print-meta* is true
  * Docstrings:
  - CLJ-2295 Eliminate duplicate doc string printing for special forms
  - CLJ-2495 prepl docstring is incorrect
  - CLJ-2169 conj has out-of-date :arglists
  * Performance:
  - CLJ-1005 Use transient map in zipmap
* Tue Jan  5 2021 Aaron Burnett <mullein@adelie.io>
- Adds rlwrap dependency for proper clj functionality
* Tue Nov  3 2020 Petr Cervinka <petr@cervinka.net>
- Fix could not find or load main class clojure.main (boo#1178408)
- Add missing clojure/libexec/exec.jar (boo#1178408)
- Add tool version to package to increase version visibility
- Apply spec-cleaner
- Update to 1.10.1.727
  * Fix clj -X:deps tree adding tools.deps.alpha to tree
  * Fix clj -X:deps mvn-pom adding tools.deps.alpha to pom deps
  * Fix clj -X:deps git-resolve-tags not working
  * TDEPS-169 - Fix clj -X:deps mvn-install on jar to also install embedded pom
  * Fix clj -Spom not respecting dep modifications from -A (regression)
- Changes in 1.10.1.716
  * Make edn reading tolerant of unknown tagged literals
  * Update to latest dependencies for maven-resolver and aws-api
  * Use tools.deps.alpha 0.9.821
* Sat Oct 10 2020 Chris Coutinho <chrisbcoutinho@gmail.com>
- Update tool version to 708
- Remove _service file as it wasn't accepted by Factory
* Wed Sep 30 2020 Daniel Ziltener <dziltener@lyrion.ch>
- Updated tool version.
- Fixed macros in spec file, added _service file.
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
- Use more macros in %%files.
* Tue Jul 23 2019 Dario Maiocchi <dmaiocchi@suse.com>
- update sed to use /bin/bash for setting up the shellbang
* Tue Jul 16 2019 mvetter@suse.com
- Use clojure-tools
- Drop custom clojure.1 and clojure
- Drop suse_version macros
* Tue Jul 16 2019 mvetter@suse.com
- Require java 1.8.0
* Tue Jul 16 2019 mvetter@suse.com
- Remove PKGBUILD. Not interested in Arch package in oS devel repo
* Tue Jul 16 2019 mvetter@suse.com
- Update to 0.10.1:
  + Changelog at https://github.com/clojure/clojure/blob/master/changes.md#changes-to-clojure-in-version-1101
- Upstream ships jar instead of zip now
- Remove files installed as doc because no zip file anymore
* Tue Jul 16 2019 mvetter@suse.com
- Cleanup spec file
* Tue Aug  2 2016 kkaempf@suse.com
- Update to 1.8.0
  + Changelog at https://github.com/clojure/clojure/blob/master/changes.md#changes-to-clojure-in-version-18
  + Direct linking
  + New string functions
  + Socket server and REPL
  + Enhancements
    + Error handling
    + Documentation strings
    + Performance
  + Bug fixes
* Sun Jul  5 2015 kgronlund@suse.com
- Update to 1.7.0
  + Changelog at https://github.com/clojure/clojure/blob/master/changes.md
  + Transducers
  + Reader Conditionals
  + Keyword and Symbol Construction
  + Warn on Boxed Math
  + update - like update-in for first level
  + Faster reduce and iterator paths
  + Printing as data
  + run!
* Fri Aug 29 2014 kgronlund@suse.com
- Update to 1.6.0
* Sun Jan 12 2014 kgronlund@suse.com
- Initial version.
